@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Mail-Box-IMAP4 version 3.010.
+# This code is part of Perl distribution Mail-Box-IMAP4 version 4.000.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -10,7 +10,7 @@
 
 
 package Mail::Box::IMAP4s;{
-our $VERSION = '3.010';
+our $VERSION = '4.000';
 }
 
 use parent 'Mail::Box::IMAP4';
@@ -18,7 +18,8 @@ use parent 'Mail::Box::IMAP4';
 use strict;
 use warnings;
 
-use IO::Socket::IP;
+use Log::Report     'mail-box-imap4';
+
 use IO::Socket::SSL qw/SSL_VERIFY_NONE/;
 
 #--------------------
